include \masm32\MasmBasic\MasmBasic.inc	; http://www.masm32.com/board/index.php?topic=12460
include \masm32\macros\timers.asm	; get them from the [url=http://www.masm32.com/board/index.php?topic=770.0]Masm32 Laboratory[/url]

.data
MyR8	REAL8 152399025.0

.data?
DestR8	REAL8 ?

.code
start:
  push 1
  call ShowCpu	; print brand string and SSE level
  SleepMs =	50	; test if anything changes when changing this
  LOOP_COUNT =	1000000	; One Mio would be a typical value
  REPEAT 2
	invoke Sleep, SleepMs
	counter_begin LOOP_COUNT, HIGH_PRIORITY_CLASS
			push 152399025
			call integer_sqrt
			xchg esi, eax
	counter_end
	print str$(eax), 9, "cycles for Jack C, res=  "
	print Str$("%i", esi), 13, 10
	invoke Sleep, SleepMs
	counter_begin LOOP_COUNT, HIGH_PRIORITY_CLASS
		movlps xmm0, MyR8
		sqrtsd xmm1, xmm0
		movlps DestR8, xmm1
	counter_end
	print str$(eax), 9, "cycles for sqrtsd, res=  "
	print Str$("%i", DestR8), 13, 10
	invoke Sleep, 100
	counter_begin LOOP_COUNT, HIGH_PRIORITY_CLASS
		push 152399025
		fild dword ptr [esp]
		fsqrt
		fistp dword ptr [esp]
		pop esi
	counter_end
	print str$(eax), 9, "cycles for fsqrt, res=   "
	print str$(esi), 13, 10
	invoke Sleep, 100
	counter_begin LOOP_COUNT, HIGH_PRIORITY_CLASS
		void Sqrt(152399025)
	counter_end
	print str$(eax), 9, "cycles for MB Sqrt, res= "
	print Str$("%i", MbDebugR10), 13, 10
	print chr$(13, 10)
  ENDM

  inkey chr$(13, 10, "--- ok ---", 13)
  exit

integer_sqrt proc	; almost identical to Jack Crenshaw's [url=http://www.embedded-systems.com/98/9802fe2.htm]Listing 4[/url]
root	equ eax
tmp	equ ebx
i	equ ecx
rem	equ edx
number equ dword ptr [esp+4]
  xor rem, rem
  xor root, root
  push 16
  pop i
  .Repeat
	shl root, 1					; root <<= 1
	mov tmp, number
	shr tmp, 30
	lea rem, [4*rem+tmp]		; rem = ((rem << 2) + (a >> 30))
	shl number, 2				; a <<= 2 ???
	.if root<rem
		inc root
		sub rem, root			; rem -= root
		inc root
	.endif
	dec i
  .Until Zero?
  shr root, 1
  ret 4
integer_sqrt endp

ShowCpu proc	; mode:DWORD
COMMENT @ Usage: 
  push 0, call ShowCpu	; simple, no printing, just returns SSE level
  push 1, call ShowCpu	; prints the brand string and returns SSE level@
  pushad
  sub esp, 80	; create a buffer for the brand string
  mov edi, esp		; point edi to it
  xor ebp, ebp
  .Repeat
  	lea eax, [ebp+80000002h]
	db 0Fh, 0A2h	; cpuid 80000002h-80000004h
	stosd
	mov eax, ebx
	stosd
	mov eax, ecx
	stosd
	mov eax, edx
	stosd
	inc ebp
  .Until ebp>=3
  push 1
  pop eax
  db 0Fh, 0A2h		; cpuid 1
  xor ebx, ebx		; CpuSSE
  xor esi, esi		; add zero plus the carry flag
  bt edx, 25		; edx bit 25, SSE1
  adc ebx, esi
  bt edx, 26		; edx bit 26, SSE2
  adc ebx, esi
  bt ecx, esi		; ecx bit 0, SSE3
  adc ebx, esi
  bt ecx, 9			; ecx bit 9, SSE4
  adc ebx, esi
  dec dword ptr [esp+4+32+80]	; dec mode in stack
  .if Zero?
	mov edi, esp	; restore pointer to brand string
  	.Repeat				
		.Break .if byte ptr [edi]!=32	; mode was 1, so show a string but skip leading blanks
		inc edi
	.Until 0
	.if byte ptr [edi]<32
		print chr$("pre-P4")
	.else
		print edi	; CpuBrand
	.endif
	.if ebx
		print chr$(32, 40, "SSE")	; info on SSE level, 40=(
		print str$(ebx), 41, 13, 10	; 41=)
	.endif
  .endif
  add esp, 80		; discard brand buffer (after printing!)
  mov [esp+32-4], ebx	; move ebx into eax stack position - returns eax to main for further use
  ifdef MbBufferInit
	call MbBufferInit
  endif
  popad
  ret 4
ShowCpu endp

end start

RichMasm options:

OPT_Tmp2Asm	1
OPT_Assembler	ml
OPT_Wait	0

Check also the [url=\masm32\RichMasm\RES\TimingsMacro.asc]timings macro[/url]